/* -------------------------------------------------------------------------- 
 * Copyright (c) 2018-2019 Kneron Inc. All rights reserved.
 *
 *      Name:    main.c
 *      Purpose: Kneron NCPU
 *
 *---------------------------------------------------------------------------*/

#include <string.h>
#include "cmsis_os2.h"

#include "dbg_print.h"

#include "kdpio.h"
#include "kdpapp.h"

extern void SystemCoreClockUpdate(void);

/* user-defined model-related CPU-OP/Pre-Processing/Post-Processing functions */
extern int user_nearest_upsample(int cpu_op, struct kdp_image_s *image_p);
extern int user_zero_upsample(int cpu_op, struct kdp_image_s *image_p);
extern int user_pre_yolo(int model_id, struct kdp_image_s *image_p);
extern int user_post_yolo(int model_id, struct kdp_image_s *image_p);

/*----------------------------------------------------------------------------
 *      Main: Initialize OS Kernel and NCPU SDK
 *---------------------------------------------------------------------------*/
int main(void)
{
    SystemCoreClockUpdate();

    osKernelInitialize();

    /* register user cpu op functions */
    kdpio_cpu_op_register(NEAREST_UPSAMPLE, user_nearest_upsample);
    kdpio_cpu_op_register(ZERO_UPSAMPLE, user_zero_upsample);

    /* register pre-processing functions */
    // demo only
    //kdpio_pre_processing_register(TINY_YOLO_V3_224_224_3, user_pre_yolo);

    /* register user post-processing functions */
    kdpio_post_processing_register(TINY_YOLO_V3_224_224_3, user_post_yolo);

    // for face_detection and landmark here using Kneron app functions
    kdpio_post_processing_register(KNERON_FD_MASK_MBSSD_200_200_3, post_ssd_face_detection);
    kdpio_post_processing_register(KNERON_LM_5PTS_ONET_56_56_3, post_face_landmark_onet_5p);

    kdpio_sdk_init();

    if (osKernelGetState() == osKernelReady)
    {
        osKernelStart();
    }

    while (1)
        ;
}
