/*
 * Kneron Main Entry driver
 *
 * Copyright (C) 2020 Kneron, Inc. All rights reserved.
 *
 */

#include "cmsis_os2.h" // ARM::CMSIS:RTOS2:Keil RTX5

#include <stdint.h>
#include <stdlib.h>
#include <string.h>

#include "kp_struct.h"
#include "kmdw_inference_app.h"
#include "kdp2_usb_companion.h"

#include "kdp2_inf_app_yolo.h"
#include "demo_customize_inf_single_model.h"
#include "demo_customize_inf_multiple_models.h"

extern void SystemCoreClockUpdate(void);

/* Kneron usb companion interface implementation to work with PLUS host SW */
extern void main_init_usboot(void);

static void app_func(void *inf_input_buf)
{
    // check header stamp
    kp_inference_header_stamp_t *header_stamp = (kp_inference_header_stamp_t *)inf_input_buf;
    uint32_t job_id = header_stamp->job_id;

    switch (job_id)
    {
    case KDP2_INF_ID_APP_YOLO:
        kdp2_app_yolo_inference(job_id, inf_input_buf);
        break;
    case KDP2_JOB_ID_APP_YOLO_CONFIG_POST_PROC:
        kdp2_app_yolo_config_post_process_parameters(job_id, inf_input_buf);
        break;
    case DEMO_KL520_CUSTOMIZE_INF_SINGLE_MODEL_JOB_ID: // a demo code implementation in SCPU for user-defined/customized infernece from one model
        demo_customize_inf_single_model(job_id, inf_input_buf);
        break;
    case DEMO_KL520_CUSTOMIZE_INF_MULTIPLE_MODEL_JOB_ID: // a demo code implementation in SCPU for user-defined/customized infernece from two models
        demo_customize_inf_multiple_models(job_id, inf_input_buf);
        break;
    default:
        kmdw_inference_app_send_status_code(job_id, KP_FW_ERROR_UNKNOWN_APP);
        break;
    }
}

/**
 * @brief main, main function
 */
int main(void)
{
    SystemCoreClockUpdate(); // System Initialization
    osKernelInitialize();    // Initialize CMSIS-RTOS

    /* SDK main init for companion mode */
    main_init_usboot();

    /* initialize inference app */
    /* register APP functions */
    /* specify depth of inference queues */
    kmdw_inference_app_init(app_func, 10, 10);

    /* start an interface implementation as input/ouput to co-work with inference framework */
    // this can be changed by other interface implementation
    kdp2_usb_companion_init();

    /* Start RTOS Kernel */
    if (osKernelGetState() == osKernelReady)
    {
        osKernelStart();
    }

    while (1)
    {
    }
}
